<?php
/*
 * Plugin name: Grimlock for LearnDash
 * Plugin URI:  http://www.themosaurus.com
 * Description: Adds integration features for Grimlock and LearnDash.
 * Author:      Themosaurus
 * Author URI:  http://www.themosaurus.com
 * Version:     1.0.11
 * License:     GPL-2.0+
 * License URI: http://www.gnu.org/licenses/gpl-2.0.txt
 * Text Domain: grimlock-learndash
 * Domain Path: /languages
 */

// Exit if accessed directly.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

define( 'GRIMLOCK_LEARNDASH_VERSION',               '1.0.11' );
define( 'GRIMLOCK_LEARNDASH_MIN_GRIMLOCK_VERSION',  '1.3.0' );
define( 'GRIMLOCK_LEARNDASH_PLUGIN_FILE',     __FILE__ );
define( 'GRIMLOCK_LEARNDASH_PLUGIN_DIR_PATH', plugin_dir_path( __FILE__ ) );
define( 'GRIMLOCK_LEARNDASH_PLUGIN_DIR_URL',  plugin_dir_url( __FILE__ ) );


// Initialize update checker
require 'libs/plugin-update-checker/plugin-update-checker.php';
Puc_v4_Factory::buildUpdateChecker(
	'http://files.themosaurus.com/grimlock-learndash/version.json',
	__FILE__,
	'grimlock-learndash'
);

/**
 * Display notice if Grimlock version doesn't match minimum requirement
 */
function grimlock_learndash_dependency_notice() {
	$url = self_admin_url( 'update-core.php?action=do-plugin-upgrade&plugins=' ) . urlencode( plugin_basename( GRIMLOCK_PLUGIN_FILE ) );
	$url = wp_nonce_url( $url, 'upgrade-core' ); ?>
	<div class="notice notice-error">
		<p><?php printf( esc_html__( '%1$sGrimlock for LearnDash%2$s requires %1$sGrimlock %3$s%2$s to continue running properly. Please %4$supdate Grimlock.%5$s', 'grimlock-learndash' ), '<strong>', '</strong>', GRIMLOCK_LEARNDASH_MIN_GRIMLOCK_VERSION, '<a href="' . esc_url( $url ) . '">', "</a>" ); ?></p>
	</div>
	<?php
}

/**
 * Load plugin.
 */
function grimlock_learndash_loaded() {
	if ( version_compare( GRIMLOCK_VERSION, GRIMLOCK_LEARNDASH_MIN_GRIMLOCK_VERSION, '<' ) ) {
		add_action( 'admin_notices', 'grimlock_learndash_dependency_notice' );
		return;
	}

	require_once 'inc/class-grimlock-learndash.php';

	global $grimlock_learndash;
	$grimlock_learndash = new Grimlock_LearnDash();

	do_action( 'grimlock_learndash_loaded' );
}
add_action( 'grimlock_loaded', 'grimlock_learndash_loaded' );

/**
 * Add support for Grimlock BuddyPress.
 *
 * @since 1.0.6
 */
function grimlock_learndash_buddypress_loaded() {
	require_once 'inc/buddypress/class-grimlock-learndash-buddypress.php';

	global $grimlock_learndash_buddypress;
	$grimlock_learndash_buddypress = new Grimlock_LearnDash_BuddyPress();

	do_action( 'grimlock_learndash_buddypress_loaded' );
}
add_action( 'grimlock_buddypress_loaded', 'grimlock_learndash_buddypress_loaded' );
