<?php
/**
 * Grimlock_LearnDash_Button_Customizer Class
 *
 * @author  themosaurus
 * @since   1.0.0
 * @package grimlock-learndash
 */

// Exit if accessed directly.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * The Grimlock Customizer class for LearnDash buttons.
 */
class Grimlock_LearnDash_Button_Customizer {
	/**
	 * Setup class.
	 *
	 * @since 1.0.0
	 */
	public function __construct() {
		add_filter( 'grimlock_button_customizer_elements',                          array( $this, 'add_elements'                          ), 10, 1 );
		add_filter( 'grimlock_button_customizer_primary_elements',                  array( $this, 'add_primary_elements'                  ), 10, 1 );
		add_filter( 'grimlock_button_customizer_primary_color_elements',            array( $this, 'add_primary_color_elements'            ), 10, 1 );
		add_filter( 'grimlock_button_customizer_primary_background_color_elements', array( $this, 'add_primary_background_color_elements' ), 10, 1 );
		add_filter( 'grimlock_button_customizer_primary_background_color_outputs',  array( $this, 'add_primary_background_color_outputs'  ), 10, 1 );
		add_filter( 'grimlock_button_customizer_secondary_elements',                array( $this, 'add_secondary_elements'                ), 10, 1 );
		add_filter( 'grimlock_button_customizer_border_radius_elements',            array( $this, 'add_border_radius_elements'            ), 10, 1 );
		add_filter( 'grimlock_button_customizer_secondary_color_outputs',           array( $this, 'add_secondary_color_outputs'           ), 10, 1 );
	}

	/**
	 * Add CSS selectors to the array of CSS selectors for the button.
	 *
	 * @since 1.0.0
	 *
	 * @param  array $elements The array of CSS selectors for the button.
	 *
	 * @return array           The updated array of CSS selectors for the button.
	 */
	public function add_elements( $elements ) {
		return array_merge( $elements, array(
			'.ld-course-list-items .btn.btn-primary',
			'.learndash .course-pager a',
			'.learndash-wrapper .ld-button',
			'div.ld-content-actions > a.ld-primary-color',
			'.bp-group-discussion .button',
			'.ld_course_grid > .thumbnail .caption .ld_course_grid_button a.btn-primary',
			'.ld-course-list-items .ld_course_grid .btn',
		) );
	}

	/**
	 * Add CSS selectors to the array of CSS selectors for the primary button.
	 *
	 * @since 1.0.0
	 *
	 * @param  array $elements The array of CSS selectors for the primary button.
	 *
	 * @return array           The updated array of CSS selectors for the primary button.
	 */
	public function add_primary_elements( $elements ) {
		return array_merge( $elements, array(
			'.btn-join',
			'#btn-join',
			'.learndash_checkout_buttons input.btn-join[type="button"]',
			'a#quiz_continue_link',
			'#ld_course_list .btn.btn-primary',
			'.learndash .course-pager a',
			'.learndash-wrapper .ld-button',
			'.learndash-wrapper .ld-expand-button',
			'.learndash-wrapper .ld-expand-button.ld-button-alternate .ld-icon',
			'div.ld-content-actions > a.ld-primary-color',
			'.learndash-wrapper .ld-breadcrumbs .ld-status.ld-status-progress',
			'.learndash-wrapper .wpProQuiz_content .wpProQuiz_button',
			'.learndash-wrapper .wpProQuiz_content .wpProQuiz_button2',
			'.learndash-wrapper .wpProQuiz_reviewDiv .wpProQuiz_reviewQuestion li.wpProQuiz_reviewQuestionTarget',
			'.learndash-wrapper .wpProQuiz_content form[name=uploadEssay] input[type=submit]',
			'.learndash-wrapper .wpProQuiz_graded_points',
			'.learndash-wrapper .wpProQuiz_points',
			'.ld_course_grid > .thumbnail .caption .ld_course_grid_button a.btn-primary',
			'.ld-course-list-items .ld_course_grid .thumbnail.course .ld_course_grid_price',
			'.learndash-wrapper .ld-focus .ld-focus-sidebar .ld-course-navigation-heading',
			'.learndash-wrapper .ld-focus .ld-focus-sidebar .ld-focus-sidebar-trigger',
			'.learndash-wrapper .ld-focus .ld-focus-header .ld-user-menu .ld-user-menu-items a',
			'.learndash-wrapper .ld-quiz-actions input[name=restartQuiz]',
			'.user_has_no_access .is_not_sample .ld-status-icon.ld-status-incomplete',
		) );
	}

	/**
	 * Add CSS selectors to the array of CSS selectors for the primary button color.
	 *
	 * @since 1.0.0
	 *
	 * @param  array $elements The array of CSS selectors for the primary button color.
	 *
	 * @return array           The updated array of CSS selectors for the primary button color.
	 */
	public function add_primary_color_elements( $elements ) {
		return array_merge( $elements, array(
			'.wpProQuiz_toplistTable th',
			'.learndash-wrapper .ld-table-list .ld-table-list-header',
			'.learndash-wrapper .ld-focus .ld-focus-sidebar .ld-course-navigation-heading h3',
		) );
	}

	/**
	 * Add CSS selectors to the array of CSS selectors for the primary button background color.
	 *
	 * @since 1.0.0
	 *
	 * @param  array $elements The array of CSS selectors for the primary button background color.
	 *
	 * @return array           The updated array of CSS selectors for the primary button background color.
	 */
	public function add_primary_background_color_elements( $elements ) {
		return array_merge( $elements, array(
			'.wpProQuiz_content .wpProQuiz_time_limit .wpProQuiz_progress',
			'.wpProQuiz_toplistTable th',
			'.learndash-wrapper .ld-table-list .ld-table-list-header',
			'.learndash-wrapper .ld-tabs .ld-tabs-navigation .ld-tab.ld-active:after',
			'.learndash-wrapper .ld-focus .ld-focus-header .ld-user-menu .ld-user-menu-items',
		) );
	}

	/**
	 * Add selectors and properties to the CSS rule-set for the primary button background color.
	 *
	 * @since 1.0.0
	 *
	 * @param  array $outputs The array of CSS selectors and properties for the primary button background color.
	 *
	 * @return array          The updated array of CSS selectors for the primary button background color.
	 */
	public function add_primary_background_color_outputs( $outputs ) {
		return array_merge( $outputs, array(
			array(
				'element' => implode( ',', array(
					'.learndash-wrapper .ld-table-list .ld-table-list-item .ld-table-list-title a:hover',
					'.learndash-wrapper .ld-item-list .ld-item-list-item a.ld-item-name:hover',
					'.learndash-wrapper .ld-tabs .ld-tabs-navigation .ld-tab.ld-active',
					'.learndash-wrapper .ld-status-unlocked',
					'.learndash-wrapper .ld-table-list a.ld-table-list-item-preview:hover',
					'.learndash-wrapper .ld-breadcrumbs .ld-breadcrumbs-segments span a:hover',
					'.learndash-wrapper .ld-tabs .ld-tabs-content .ld-tab-content ul > li a:hover',
					'.learndash-wrapper .ld-course-navigation .ld-lesson-item.ld-is-current-lesson .ld-lesson-item-preview-heading',
					'.learndash-wrapper .ld-course-navigation .ld-lesson-item.ld-is-current-lesson .ld-lesson-title',
					'.learndash-wrapper .ld-button.ld-button-transparent',
					'.learndash-wrapper .ld-button.ld-button-transparent:hover',
					'.learndash-wrapper .ld-button.ld-button-transparent:active',
					'.learndash-wrapper .ld-button.ld-button-transparent:focus',
				) ),
				'property' => 'color',
			),
			array(
				'element' => implode( ',', array(
					'.learndash-wrapper .ld-expand-button.ld-button-alternate',
				) ),
				'property' => 'color',
				'suffix'   => '!important',
			),
			array(
				'element' => implode( ',', array(
					'.wpProQuiz_content .wpProQuiz_response',
					'.wpProQuiz_content .wpProQuiz_reviewQuestion li.wpProQuiz_reviewQuestionTarget',
					'.learndash-wrapper .wpProQuiz_content .wpProQuiz_questionListItem:not(.wpProQuiz_answerIncorrect):not(.wpProQuiz_answerCorrect) label.is-selected',
					'.learndash-wrapper .wpProQuiz_content .wpProQuiz_questionListItem:not(.wpProQuiz_answerIncorrect):not(.wpProQuiz_answerCorrect) label:focus-within',
					'.learndash-wrapper .ld-course-navigation .ld-lesson-item.ld-is-current-lesson .ld-lesson-item-preview-heading .ld-status-incomplete',
					'.learndash-wrapper .ld-course-navigation .ld-lesson-item.ld-is-current-lesson .ld-lesson-title .ld-status-incomplete',
				) ),
				'property' => 'border-color',
			),
			array(
				'element' => implode( ',', array(
					'.learndash_course_materials > h4:after',
					'.learndash_course_content > h4:after',
					'.learndash_lesson_materials > h4:after',
					'.learndash_topic_materials > h4:after',
					'.learndash_quizz_materials > h4:after',
					'.wpProQuiz_content > h2:after',
					'#leardash_upload_assignment td u:after',
					'#learndash_uploaded_assignments > h2:after',
				) ),
				'property' => 'border-left-color',
			),
			array(
				'element' => implode( ',', array(
					'.wpProQuiz_content .wpProQuiz_resultValue > div',
				) ),
				'property' => 'background-color',
				'suffix'   => '!important',
			),
			array(
				'element' => implode( ',', array(
					'.learndash-wrapper .ld-focus .ld-focus-header .ld-user-menu .ld-user-menu-items:before',
				) ),
				'property' => 'border-bottom-color',
			),
		) );
	}

	/**
	 * Add CSS selectors to the array of CSS selectors for the secondary button.
	 *
	 * @since 1.0.0
	 *
	 * @param  array $elements The array of CSS selectors for the secondary button.
	 *
	 * @return array           The updated array of CSS selectors for the secondary button.
	 */
	public function add_secondary_elements( $elements ) {
		return array_merge( $elements, array(
			'.wpProQuiz_content .wpProQuiz_button2',
			'.bp-group-discussion .button',
			'.learndash-wrapper .wpProQuiz_reviewDiv .wpProQuiz_reviewQuestion li.wpProQuiz_reviewQuestionTarget',
			'.learndash-wrapper .ld-quiz-actions input[name=reShowQuestion]',
		) );
	}

	/**
	 * Add CSS selectors to the array of CSS selectors for the button border radius.
	 *
	 * @since 1.0.0
	 *
	 * @param  array $elements The array of CSS selectors for the button border radius.
	 *
	 * @return array           The updated array of CSS selectors for the button border radius.
	 */
	public function add_border_radius_elements( $elements ) {
		return array_merge( $elements, array(
			'.btn-join',
			'#btn-join',
			'.learndash_checkout_buttons input.btn-join[type="button"]',
			'a#quiz_continue_link',
			'.course-img',
			'.course-meta',
			'.wpProQuiz_catOverview',
			'.wpProQuiz_content .wpProQuiz_tipp > div',
			'.wpProQuiz_content .wpProQuiz_resultTable',
			'.ld-content-actions .ld-content-action input[type="submit"]',
		) );
	}

	/**
	 * Add selectors and properties to the CSS rule-set for the primary button color.
	 *
	 * @since 1.0.0
	 *
	 * @param  array $outputs The array of CSS selectors and properties for the primary button color.
	 *
	 * @return array          The updated array of CSS selectors for the primary button color.
	 */
	public function add_secondary_color_outputs( $outputs ) {
		return array_merge( $outputs, array(
			array(
				'element' => implode( ',', array(
					'.bp-group-discussion .button',
				) ),
				'property' => 'border-color',
			),
		) );
	}

}

return new Grimlock_LearnDash_Button_Customizer();
