<?php
/**
 * Grimlock_LearnDash_Customizer Class
 *
 * @author  themosaurus
 * @since   1.0.0
 * @package grimlock-learndash
 */

// Exit if accessed directly.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * The Grimlock Customizer class for the Hero section.
 */
class Grimlock_LearnDash_Customizer extends Grimlock_Template_Customizer {
	/**
	 * Setup class.
	 *
	 * @since 1.0.0
	 */
	public function __construct() {
		$this->id      = 'learndash';
		$this->title   = esc_html__( 'LearnDash', 'grimlock-learndash' );
		$this->section = 'grimlock_learndash_customizer_section';

		add_action( 'after_setup_theme',                         array( $this, 'add_customizer_fields'           ), 20    );

		add_filter( 'body_class',                                array( $this, 'add_body_classes'                ), 10, 1 );

		add_filter( 'grimlock_customizer_controls_js_data',      array( $this, 'add_customizer_controls_js_data' ), 10, 1 );
		add_filter( 'grimlock_content_class',                    array( $this, 'add_content_classes'             ), 10, 1 );
		add_filter( 'grimlock_single_args',                      array( $this, 'change_single_args'              ), 20, 1 );
		add_filter( 'grimlock_custom_header_args',               array( $this, 'add_custom_header_args'          ), 20, 1 );
		add_filter( 'grimlock_custom_header_displayed',          array( $this, 'has_custom_header_displayed'     ), 10, 1 );
		add_filter( 'grimlock_template_sidebar_right_displayed', array( $this, 'has_sidebar_right_displayed'     ), 10, 1 );
		add_filter( 'grimlock_template_sidebar_left_displayed',  array( $this, 'has_sidebar_left_displayed'      ), 10, 1 );
		add_filter( 'grimlock_archive_customizer_is_template',   array( $this, 'archive_customizer_is_template'  ), 10, 1 );
		add_filter( 'grimlock_single_customizer_is_template',    array( $this, 'single_customizer_is_template'   ), 10, 1 );

		add_filter( 'kirki_grimlock_dynamic_css',                array( $this, 'add_dynamic_css'                 ), 10, 1 );
	}

	/**
	 * Add arguments using theme mods to customize the Custom Header.
	 *
	 * @since 1.0.0
	 *
	 * @param array $args The default arguments to render the Custom Header.
	 *
	 * @return array      The arguments to render the Custom Header.
	 */
	public function add_custom_header_args( $args ) {
		$args = parent::add_custom_header_args( $args );

		if ( $this->is_template() ) {
			// TODO: Consider moving to parent method. Same goes for similar lines from Customizer classes in sibling add-ons.
			$args['background_image'] = $this->get_theme_mod( 'learndash_custom_header_background_image' );
		}
		return $args;
	}

	/**
	 * Check if the current template is the expected template.
	 *
	 * @since 1.0.0
	 *
	 * @return bool True when the template is the expected template, false otherwise.
	 */
	protected function is_template() {
		return apply_filters( 'grimlock_learndash_customizer_is_template', false );
	}

	/**
	 * Disinherit archive customizer settings
	 *
	 * @param bool $default True if we are on a default archive page
	 *
	 * @return bool
	 */
	public function archive_customizer_is_template( $default ) {
		return $default && ! $this->is_template();
	}

	/**
	 * Disinherit single customizer settings
	 *
	 * @param bool $default True if we are on a default single page
	 *
	 * @return bool
	 */
	public function single_customizer_is_template( $default ) {
		return $default && ! $this->is_template();
	}

	/**
	 * Add tabs to the Customizer to group controls.
	 *
	 * @since 1.0.0
	 *
	 * @param  array $js_data The array of data for the Customizer controls.
	 *
	 * @return array          The filtred array of data for the Customizer controls.
	 */
	public function add_customizer_controls_js_data( $js_data ) {
		$js_data['tabs'][$this->section] = array(
			array(
				'label' => esc_html__( 'General', 'grimlock-learndash' ),
				'class' => 'learndash-general-tab',
				'controls' => array(
					"{$this->section}_heading_10",
					'learndash_custom_header_displayed',
				),
			),
			array(
				'label' => esc_html__( 'Layout', 'grimlock-learndash' ),
				'class' => 'learndash-layout-tab',
				'controls' => array(
					'learndash_custom_header_layout',
					"{$this->section}_divider_110",
					'learndash_custom_header_container_layout',
					"{$this->section}_divider_120",
					'learndash_layout',
					'learndash_sidebar_mobile_displayed',
					"{$this->section}_divider_140",
					'learndash_container_layout',
				),
			),
			array(
				'label' => esc_html__( 'Style', 'grimlock-learndash' ),
				'class' => 'learndash-style-tab',
				'controls' => array(
					'learndash_custom_header_background_image',
					'learndash_custom_header_padding_y',
					"{$this->section}_divider_220",
					'learndash_content_padding_y',
				),
			),
		);
		return $js_data;
	}

	/**
	 * Change post arguments using to customize the LearnDash course.
	 *
	 * @since 1.0.0
	 *
	 * @param array $args The default arguments to render the post.
	 *
	 * @return array      The arguments to render the post.
	 */
	public function change_single_args( $args ) {
		if ( $this->is_template() ) {
			$args['post_thumbnail_displayed'] = false;
		}
		return $args;
	}

	/**
	 * Register default values, settings and custom controls for the Theme Customizer.
	 *
	 * @since 1.0.0
	 */
	public function add_customizer_fields() {
		$this->defaults = apply_filters( 'grimlock_learndash_customizer_defaults', array(
			'learndash_custom_header_displayed'           => has_header_image(),

			'learndash_custom_header_layout'              => '6-6-cols-left-reverse',
			'learndash_custom_header_container_layout'    => 'classic',

			'learndash_layout'                            => '12-cols-left',
			'learndash_sidebar_mobile_displayed'          => true,
			'learndash_container_layout'                  => 'classic',

			'learndash_custom_header_background_image'    => get_header_image(),
			'learndash_custom_header_padding_y'           => GRIMLOCK_SECTION_PADDING_Y,
			'learndash_content_padding_y'                 => GRIMLOCK_CONTENT_PADDING_Y,
		) );

		$this->add_section(                              array( 'priority' => 120 ) );

		$this->add_heading_field(                        array( 'priority' => 10, 'label' => esc_html__( 'Display', 'grimlock' ) ) );
		$this->add_custom_header_displayed_field(        array( 'priority' => 10  ) );

		$this->add_custom_header_layout_field(           array( 'priority' => 100 ) );
		$this->add_divider_field(                        array( 'priority' => 110 ) );
		$this->add_custom_header_container_layout_field( array( 'priority' => 110 ) );
		$this->add_divider_field(                        array( 'priority' => 120 ) );
		$this->add_layout_field(                         array( 'priority' => 120 ) );
		$this->add_sidebar_mobile_displayed_field(       array( 'priority' => 130 ) );
		$this->add_divider_field(                        array( 'priority' => 140 ) );
		$this->add_container_layout_field(               array( 'priority' => 140 ) );

		$this->add_custom_header_background_image_field( array( 'priority' => 200 ) );
		$this->add_custom_header_padding_y_field(        array( 'priority' => 210 ) );
		$this->add_divider_field(                        array( 'priority' => 220 ) );
		$this->add_content_padding_y_field(              array( 'priority' => 230 ) );
	}

	/**
	 * Add a Kirki section in the Customizer.
	 *
	 * @since 1.0.0
	 *
	 * @param array $args
	 */
	protected function add_section( $args = array() ) {
		if ( class_exists( 'Kirki' ) ) {
			Kirki::add_section( $this->section, apply_filters( "{$this->section}_args", array(
				'title'    => $this->title,
				'priority' => isset( $args['priority'] ) ? $args['priority'] : 10,
			) ) );
		}
	}

	/**
	 * Add a Kirki image field to set the background image for the Custom Header in the Customizer.
	 *
	 * @since 1.0.5
	 *
	 * @param array $args The array of arguments for the Kirki field.
	 */
	protected function add_custom_header_background_image_field( $args = array() ) {
		if ( class_exists( 'Kirki' ) ) {
			$args = wp_parse_args( $args, array(
				'type'     => 'image',
				'section'  => $this->section,
				'label'    => esc_html__( 'Header Image', 'grimlock-learndash' ),
				'settings' => 'learndash_custom_header_background_image',
				'default'  => $this->get_default( 'learndash_custom_header_background_image' ),
				'priority' => 10,
			) );

			Kirki::add_field( 'grimlock', apply_filters( 'grimlock_learndash_customizer_custom_header_background_image_field_args', $args ) );
		}
	}
}

return new Grimlock_LearnDash_Customizer();
