<?php
/**
 * Grimlock_LearnDash_Table_Customizer Class
 *
 * @author  themosaurus
 * @since   1.0.0
 * @package grimlock-learndash
 */

// Exit if accessed directly.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * The Grimlock Customizer class for LearnDash buttons.
 */
class Grimlock_LearnDash_Table_Customizer {
	/**
	 * Setup class.
	 *
	 * @since 1.0.0
	 */
	public function __construct() {
		add_filter( 'grimlock_table_customizer_striped_background_color_elements', array( $this, 'add_striped_background_color_elements' ), 10, 1 );
		add_filter( 'grimlock_table_customizer_striped_background_color_outputs',  array( $this, 'add_striped_background_color_outputs'  ), 10, 1 );
	}

	/**
	 * Add CSS selectors to the array of CSS selectors for the striped table row background color.
	 *
	 * @since 1.0.0
	 *
	 * @param  array $elements The array of CSS selectors for the striped table row background color.
	 *
	 * @return array           The updated array of CSS selectors for the striped table row background color.
	 */
	public function add_striped_background_color_elements( $elements ) {
		return array_merge( $elements, array(
			'dd.course_progress',
			'.wpProQuiz_content .wpProQuiz_resultTable',
			'.wpProQuiz_toplistTrOdd',
			'.wpProQuiz_catOverview',
			'.wpProQuiz_content .wpProQuiz_tipp > div',
			'.wpProQuiz_quiz .wpProQuiz_list .wpProQuiz_listItem',
			'.wpProQuiz_content .wpProQuiz_matrixSortString',
			'#learndash_lesson_topics_list ul > li.nth-of-type-odd',
			'.learndash-wrapper .ld-table-list .ld-table-list-item-expanded .ld-table-list .ld-table-list-header',
			'.learndash-wrapper .ld-table-list .ld-table-list-item-expanded .ld-table-list .ld-table-list-items',
			'.learndash-wrapper .ld-table-list .ld-table-list-footer',
			'.learndash-wrapper .ld-status:not([class*="ld-status-"])',
			'.user_has_no_access .ld-item-list .ld-item-list-item.is_not_sample',
			'.user_has_no_access .ld-item-list .ld-item-list-item .ld-item-list-item-expanded:before',
			'.learndash-wrapper .ld-item-list .ld-item-list-item .ld-item-list-item-expanded .ld-progress',
			'.learndash-wrapper .ld-status-unlocked',
			'.learndash-wrapper .ld-file-upload',
			'.learndash-wrapper .wpProQuiz_content .wpProQuiz_time_limit',
			'.learndash-wrapper .wpProQuiz_reviewDiv .wpProQuiz_reviewQuestion',
			'.wpProQuiz_content .wpProQuiz_addToplist',
			'.learndash-wrapper .ld-status:not([class*="complete"]):not([class*="warning"]):not([class*="warning"]):not([class*="waiting"])',
			'.learndash-wrapper.learndash-widget .ld-progress .ld-progress-bar',
			'.learndash-wrapper .ld-progress .ld-progress-bar',
			'.learndash-wrapper .ld-course-navigation .ld-lesson-item-expanded',
			'.ld-course-info-my-courses',
			'[class*="sfwd-courses-widget"] ul li',
			'[class*="sfwd-quiz-widget"] ul li',
			'[class*="sfwd-lessons-widget"] ul li',
			'.widget_lduserstatus .learndash-wrapper .ld-user-status.ld-is-widget .ld-item-list .ld-item-list-item',
			'.learndash-wrapper .ld-status-in-progress',
			'.learndash-wrapper .ld-status-incomplete.ld-status-icon',
			'.learndash-wrapper .wpProQuiz_content .wpProQuiz_tipp>div',
		) );
	}

	/**
	 * Add selectors and properties to the CSS rule-set for the striped table row background color.
	 *
	 * @since 1.0.0
	 *
	 * @param  array $outputs The array of CSS selectors and properties for the striped table row background color.
	 *
	 * @return array          The updated array of CSS selectors for the striped table row background color.
	 */
	public function add_striped_background_color_outputs( $outputs ) {
		return array_merge( $outputs, array(
			array(
				'element'  => implode( ',', array(
					'.wpProQuiz_content .wpProQuiz_matrixSortString',
					'.learndash-wrapper .ld-table-list .ld-table-list-items',
					'.learndash-wrapper .ld-item-list .ld-item-list-item .ld-item-list-item-preview .ld-status-icon',
					'.learndash-wrapper .wpProQuiz_content .wpProQuiz_questionListItem .wpProQuiz_sortable',
					'.wpProQuiz_content .wpProQuiz_addToplist',
				) ),
				'property' => 'border-color',
			),
			array(
				'element'  => implode( ',', array(
					'.learndash-wrapper .ld-table-list .ld-table-list-item-expanded .ld-table-list .ld-table-list-item:first-child',
				) ),
				'property' => 'border-top-color',
			),
			array(
				'element'  => implode( ',', array(
					'.learndash-wrapper .wpProQuiz_reviewDiv',
					'.learndash-wrapper .ld-course-navigation .ld-lesson-item',
				) ),
				'property' => 'border-bottom-color',
			),
			array(
				'element'  => implode( ',', array(
					'#learndash_course_content .learndash_topic_dots ul > li:nth-of-type(odd)',
					'#learndash_course_content .learndash_topic_dots .nth-of-type-odd',
					'.learndash_navigation_lesson_topics_list .nth-of-type-odd',
					'#learndash_course_content .learndash_topic_dots ul > li:hover',
				) ),
				'property' => 'background',
			),
		) );
	}

}

return new Grimlock_LearnDash_Table_Customizer();
