<?php
/**
 * Grimlock_LearnDash_Typography_Customizer Class
 *
 * @author   Themosaurus
 * @since    1.0.0
 * @package grimlock-learndash
 */

// Exit if accessed directly.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * The typography class for the Customizer.
 */
class Grimlock_LearnDash_Typography_Customizer {
	/**
	 * Setup class.
	 *
	 * @since 1.0.0
	 */
	public function __construct() {
		add_filter( 'grimlock_typography_customizer_heading_color_outputs', array( $this, 'add_heading_color_outputs' ), 10, 1 );
		add_filter( 'grimlock_typography_customizer_heading_font_outputs',  array( $this, 'add_heading_font_outputs'  ), 10, 1 );
	}

	/**
	 * Add selectors and properties to the CSS rule-set for the heading color.
	 *
	 * @since 1.0.0
	 *
	 * @param  array $outputs The array of CSS selectors and properties for the heading color.
	 *
	 * @return array          The updated array of CSS selectors for the heading color.
	 */
	public function add_heading_color_outputs( $outputs ) {
		return array_merge( $outputs, array(
			array(
				'element'  => implode( ',', array(
					'.ld-course-navigation a.ld-home-link:not(:hover)',
					'[class*="sfwd-courses-widget"] ul li a:not(:hover)',
					'[class*="sfwd-quiz-widget"] ul li a:not(:hover)',
					'[class*="sfwd-lessons-widget"] ul li a:not(:hover)',
					'#ld_course_info .ld-entry-title a:not(:hover)',
					'.learndash-wrapper .ld-user-status.ld-is-widget .ld-item-list .ld-item-list-item .ld-item-list-item-preview .ld-item-title',
					'.ld-course-progress-content-container > .learndash-profile-course-title',
					'.learndash-wrapper .ld-course-navigation .ld-lesson-item-section-heading .ld-lesson-section-heading',
				) ),
				'property' => 'color',
				'suffix'   => '!important',
			),
		) );
	}

	/**
	 * Add selectors and properties to the CSS rule-set for the heading font.
	 *
	 * @since 1.0.0
	 *
	 * @param  array $outputs The array of CSS selectors and properties for the heading font.
	 *
	 * @return array          The updated array of CSS selectors for the heading font.
	 */
	public function add_heading_font_outputs( $outputs ) {
		$elements_headings = array(
			'.ld-course-navigation .ld-home-link',
			'.learndash-wrapper .ld-user-status.ld-is-widget .ld-item-list .ld-item-list-item .ld-item-list-item-preview .ld-item-title',
			'.learndash-wrapper .ld-course-navigation .ld-lesson-item-section-heading .ld-lesson-section-heading',
		);

		return array_merge( $outputs, array(
			array(
				'element'  => implode( ',', $elements_headings ),
				'property' => 'font-family',
				'choice'   => 'font-family',
			),
			array(
				'element'  => implode( ',', $elements_headings ),
				'property' => 'text-transform',
				'choice'   => 'text-transform',
			),
			array(
				'element'  => implode( ',', $elements_headings ),
				'property' => 'font-weight',
				'choice'   => 'font-weight',
			),
			array(
				'element'  => implode( ',', $elements_headings ),
				'property' => 'font-style',
				'choice'   => 'font-style',
			),
		) );
	}
}

return new Grimlock_LearnDash_Typography_Customizer();
